@@ -46,7 +46,7 @@ moderTestXgrp <- function(dat,grp,limmaOutput=TRUE,addResults=c("lfdr","FDR","Mv
     ## see eg   https://support.bioconductor.org/p/57268/; https://www.biostars.org/p/157068/
   globFilt <- 1:nrow(dat)  # not used yet
   fit0 <- try(limma::lmFit(dat[globFilt,],datDesign))          # [sampleOrder,qcDat]
-  if(class(fit0) == "try-error") message(fxNa," check if package 'limma' is installed !?!")
+  if("try-error" %in% class(fit0)) message(fxNa," Problem running lmFit(),  check if package 'limma' is installed !?!")
   fit1 <- limma::eBayes(limma::contrasts.fit(fit0,contrasts=contr.matr))  # variant to run all contrasts at same time
   compNa <- colnames(fit1$contrasts)
   fit1$means <- rowGrpMeans(dat,grp) 
